==> apache-juneau-8.2.0-src.zip: juneau-8.2.0/juneau-core/juneau-marshall/src/main/java/org/apache/juneau/jsonschema/BeanDefMapper.java <==
// ***************************************************************************************************************************
// * Licensed to the Apache Software Foundation (ASF) under one or more contributor license agreements.  See the NOTICE file *
// * distributed with this work for additional information regarding copyright ownership.  The ASF licenses this file        *
// * to you under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance            *
// * with the License.  You may obtain a copy of the License at                                                              *
// *                                                                                                                         *
// *  http://www.apache.org/licenses/LICENSE-2.0                                                                             *
// *                                                                                                                         *
// * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an  *
// * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the        *
// * specific language governing permissions and limitations under the License.                                              *
// ***************************************************************************************************************************
package org.apache.juneau.jsonschema;

import java.net.*;

import org.apache.juneau.*;

/**
 * Interface used to retrieve identifiers and URIs for bean classes.
 */
public interface BeanDefMapper {

	/**
	 * Represents the absence of a bean definition mapper class.
	 */
	public interface Null extends BeanDefMapper {}

	/**
	 * Returns the ID for the specified class.
	 *
	 * @param cm The class.
	 * @return The ID for the specified class.
	 */
	String getId(ClassMeta<?> cm);

	/**
	 * Returns the URI for the specified class.
	 *
	 * @param cm The class.
	 * @return The URI for the specified class.
	 */
	URI getURI(ClassMeta<?> cm);

	/**
	 * Returns the URI for the specified class by its ID.
	 *
	 * @param id The class ID.
	 * @return The URI for the specified class.
	 */
	URI getURI(String id);
}

==> apache-juneau-9.0.1-src.zip: juneau-9.0.1/juneau-core/juneau-marshall/src/main/java/org/apache/juneau/jsonschema/BeanDefMapper.java <==
// ***************************************************************************************************************************
// * Licensed to the Apache Software Foundation (ASF) under one or more contributor license agreements.  See the NOTICE file *
// * distributed with this work for additional information regarding copyright ownership.  The ASF licenses this file        *
// * to you under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance            *
// * with the License.  You may obtain a copy of the License at                                                              *
// *                                                                                                                         *
// *  http://www.apache.org/licenses/LICENSE-2.0                                                                             *
// *                                                                                                                         *
// * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an  *
// * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the        *
// * specific language governing permissions and limitations under the License.                                              *
// ***************************************************************************************************************************
package org.apache.juneau.jsonschema;

import java.net.*;

import org.apache.juneau.*;

/**
 * Interface used to retrieve identifiers and URIs for bean classes.
 *
 * <h5 class='section'>See Also:</h5><ul>
 * 	<li class='link'><a class="doclink" href="../../../../index.html#jm.JsonSchemaDetails">JSON-Schema Support</a>
 * </ul>
 */
public interface BeanDefMapper {

	/**
	 * Represents the absence of a bean definition mapper class.
	 */
	public interface Void extends BeanDefMapper {}

	/**
	 * Returns the ID for the specified class.
	 *
	 * @param cm The class.
	 * @return The ID for the specified class.
	 */
	String getId(ClassMeta<?> cm);

	/**
	 * Returns the URI for the specified class.
	 *
	 * @param cm The class.
	 * @return The URI for the specified class.
	 */
	URI getURI(ClassMeta<?> cm);

	/**
	 * Returns the URI for the specified class by its ID.
	 *
	 * @param id The class ID.
	 * @return The URI for the specified class.
	 */
	URI getURI(String id);
}
